@@ -12,13 +12,15 @@ from astropy import nddata, stats
 from astropy import units as u
 from astropy.modeling import fitting
 from astropy.nddata import CCDData, StdDevUncertainty
+from astropy.nddata.bitmask import (
+    bitfield_to_boolean_mask as _bitfield_to_boolean_mask,
+)
 from astropy.units.quantity import Quantity
 from astropy.utils import deprecated, deprecated_renamed_argument
 from astropy.wcs.utils import proj_plane_pixel_area
 from packaging import version as pkgversion
 from scipy import ndimage
 
-from .extern.bitfield import bitfield_to_boolean_mask as _bitfield_to_boolean_mask
 from .log_meta import log_to_metadata
 from .utils.slices import slice_from_string
 
@@ -475,8 +477,8 @@ def subtract_overscan(
     Spaces are stripped out of the ``fits_section`` string.
 
     """
-    if not (isinstance(ccd, CCDData) or isinstance(ccd, np.ndarray)):
-        raise TypeError("ccddata is not a CCDData or ndarray object.")
+    if not isinstance(ccd, CCDData):
+        raise TypeError("ccddata is not a CCDData object.")
 
     if (overscan is not None and fits_section is not None) or (
         overscan is None and fits_section is None
@@ -818,18 +820,25 @@ def flat_correct(ccd, flat, min_value=None, norm_value=None):
 
     # If a norm_value was input and is positive, use it to scale the flat
     if norm_value is not None and norm_value > 0:
-        flat_mean_val = norm_value
+        flat_mean = (
+            norm_value if hasattr(norm_value, "unit") else norm_value * use_flat.unit
+        )
     elif norm_value is not None:
         # norm_value was set to a bad value
         raise ValueError("norm_value must be greater than zero.")
     else:
         # norm_value was not set, use mean of the image.
-        flat_mean_val = use_flat.data.mean()
+        flat_mean = use_flat.data.mean() * use_flat.unit
 
     # Normalize the flat.
-    flat_mean = flat_mean_val * use_flat.unit
     flat_normed = use_flat.divide(flat_mean)
 
+    # Set masked values to unity; the array element remains masked, but the data
+    # value is set to unity to avoid runtime divide-by-zero errors that are due
+    # to a masked value being set to 0.
+    if flat_normed.mask is not None and flat_normed.mask.any():
+        flat_normed.data[flat_normed.mask] = 1.0
+
     # divide through the flat
     flat_corrected = ccd.divide(flat_normed)
 
@@ -1278,65 +1287,6 @@ except AttributeError:
     del block_reduce, block_average, block_replicate
 
 
-def _blkavg(data, newshape):
-    """
-    Block average an array such that it has the new shape.
-
-    Parameters
-    ----------
-    data : `numpy.ndarray` or `numpy.ma.MaskedArray`
-        Data to average.
-
-    newshape : tuple
-        Tuple containing the new shape for the array.
-
-    Returns
-    -------
-    output : `numpy.ndarray` or `numpy.ma.MaskedArray`
-        An array with the new shape and the average of the pixels.
-
-    Raises
-    ------
-    TypeError
-        A type error is raised if data is not an `numpy.ndarray`.
-
-    ValueError
-        A value error is raised if the dimensions of new shape is not equal
-        to data.
-
-    Notes
-    -----
-    This is based on the scipy cookbook for rebinning:
-    http://wiki.scipy.org/Cookbook/Rebinning
-    """
-    # check to see that is in a nddata type
-    if not isinstance(data, np.ndarray):
-        raise TypeError("data is not a ndarray object.")
-
-    # check to see that the two arrays are going to be the same length
-    if len(data.shape) != len(newshape):
-        raise ValueError("newshape does not have the same dimensions as data.")
-
-    shape = data.shape
-    lenShape = len(shape)
-    # fmt: off
-    factor = np.asarray(  # noqa: F841  factor is actually used in eval
-        shape
-    ) / np.asarray(
-        newshape
-    )
-    # fmt: on
-
-    evList = (
-        ["data.reshape("]
-        + [f"newshape[{i}],int(factor[{i}])," for i in range(lenShape)]
-        + [")"]
-        + [f".mean({i + 1})" for i in range(lenShape)]
-    )
-
-    return eval("".join(evList))
-
-
 def median_filter(data, *args, **kwargs):
     """See `scipy.ndimage.median_filter` for arguments.
 
