@@ -1,31 +1,29 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 
-from functools import wraps
 import inspect
+from functools import wraps
 from itertools import chain
 
 import numpy as np
-
-from astropy.nddata import NDData
 from astropy import units as u
 from astropy.io import fits
+from astropy.nddata import NDData
 
 import ccdproc  # Really only need Keyword from ccdproc
 
 __all__ = []
 
-_LOG_ARGUMENT = 'add_keyword'
+_LOG_ARGUMENT = "add_keyword"
 
-_LOG_ARG_HELP = \
-    """
-    {arg} : str, `~ccdproc.Keyword` or dict-like, optional
+_LOG_ARG_HELP = f"""
+    {_LOG_ARGUMENT} : str, `~ccdproc.Keyword` or dict-like, optional
         Item(s) to add to metadata of result. Set to False or None to
         completely  disable logging.
         Default is to add a dictionary with a single item:
         The key is the name of this function  and the value is a string
         containing the arguments the function was called with, except the
         value of this argument.
-    """.format(arg=_LOG_ARGUMENT)
+    """
 
 
 def _insert_in_metadata_fits_safe(ccd, key, value):
@@ -41,11 +39,12 @@ def _insert_in_metadata_fits_safe(ccd, key, value):
         # Shorten, sort of...
         short_name = _short_names[key]
         if isinstance(ccd.meta, fits.Header):
-            ccd.meta['HIERARCH {0}'.format(key.upper())] = (
-                short_name, "Shortened name for ccdproc command")
+            ccd.meta[f"HIERARCH {key.upper()}"] = (
+                short_name,
+                "Shortened name for ccdproc command",
+            )
         else:
-            ccd.meta[key] = (
-                short_name, "Shortened name for ccdproc command")
+            ccd.meta[key] = (short_name, "Shortened name for ccdproc command")
         ccd.meta[short_name] = value
     else:
         ccd.meta[key] = value
@@ -64,18 +63,12 @@ def log_to_metadata(func):
     func.__doc__ = func.__doc__.format(log=_LOG_ARG_HELP)
 
     argspec = inspect.getfullargspec(func)
-    original_args, varargs, keywords, defaults = (argspec.args, argspec.varargs,
-                                                  argspec.varkw, argspec.defaults)
-    # original_args = argspec.args
-    # varargs = argspec.varargs
-    # keywords = argspec.varkw
-    # defaults = argspec.defaults
-
-    # Grab the names of positional arguments for use in automatic logging
-    try:
-        original_positional_args = original_args[:-len(defaults)]
-    except TypeError:
-        original_positional_args = original_args
+    original_args, _, _, defaults = (
+        argspec.args,
+        argspec.varargs,
+        argspec.varkw,
+        argspec.defaults,
+    )
 
     # Add logging keyword and its default value for docstring
     original_args.append(_LOG_ARGUMENT)
@@ -86,8 +79,7 @@ def log_to_metadata(func):
     defaults.append(True)
 
     signature_with_arg_added = inspect.signature(func)
-    signature_with_arg_added = "{0}{1}".format(func.__name__,
-                                               signature_with_arg_added)
+    signature_with_arg_added = f"{func.__name__}{signature_with_arg_added}"
     func.__doc__ = "\n".join([signature_with_arg_added, func.__doc__])
 
     @wraps(func)
@@ -108,12 +100,13 @@ def log_to_metadata(func):
                 key = func.__name__
                 # Get names of arguments, which may or may not have
                 # been called as keywords.
-                positional_args = original_args[:len(args)]
+                positional_args = original_args[: len(args)]
 
                 all_args = chain(zip(positional_args, args), kwd.items())
-                all_args = ["{0}={1}".format(name,
-                                            _replace_array_with_placeholder(val))
-                            for name, val in all_args]
+                all_args = [
+                    f"{name}={_replace_array_with_placeholder(val)}"
+                    for name, val in all_args
+                ]
                 log_val = ", ".join(all_args)
                 log_val = log_val.replace("\n", "")
                 meta_dict = {key: log_val}
@@ -155,6 +148,6 @@ def _replace_array_with_placeholder(value):
         return_type_not_value = length > 1
 
     if return_type_not_value:
-        return "<{0}>".format(value.__class__.__name__)
+        return f"<{value.__class__.__name__}>"
     else:
         return value
