@@ -11,11 +11,9 @@ from astropy.nddata import CCDData, StdDevUncertainty
 from astropy.units.quantity import Quantity
 from astropy.utils.exceptions import AstropyUserWarning
 from astropy.wcs import WCS
-from numpy.testing import assert_array_equal
 
 from ccdproc.core import (
     Keyword,
-    _blkavg,
     ccd_process,
     cosmicray_lacosmic,
     cosmicray_median,
@@ -72,7 +70,7 @@ def test_create_deviation(u_image, u_gain, u_readnoise, expect_success):
             expected_var = np.sqrt(2 * ccd_data.data + 5**2) / 2
         else:
             expected_var = np.sqrt(ccd_data.data + 5**2)
-        np.testing.assert_array_equal(ccd_var.uncertainty.array, expected_var)
+        np.testing.assert_allclose(ccd_var.uncertainty.array, expected_var)
         assert ccd_var.unit == ccd_data.unit
         # Uncertainty should *not* have any units -- does it?
         with pytest.raises(AttributeError):
@@ -104,7 +102,7 @@ def test_create_deviation_from_negative_2():
     mask = ccd_data.data < 0
     ccd_data.data[mask] = 0
     expected_var = np.sqrt(ccd_data.data + readnoise.value**2)
-    np.testing.assert_array_equal(ccd_var.uncertainty.array, expected_var)
+    np.testing.assert_allclose(ccd_var.uncertainty.array, expected_var)
 
 
 def test_create_deviation_keywords_must_have_unit():
@@ -190,7 +188,7 @@ def test_subtract_overscan(median, transpose, data_rectangle):
     assert (ccd_data_fits_section.data[oscan_region] == 0).all()
 
     # Do both ways of subtracting overscan give exactly the same result?
-    np.testing.assert_array_equal(
+    np.testing.assert_allclose(
         ccd_data_overscan[science_region], ccd_data_fits_section[science_region]
     )
 
@@ -305,6 +303,9 @@ def test_subtract_overscan_fails():
     # Does a fits_section which is not a string raise an error?
     with pytest.raises(TypeError):
         subtract_overscan(ccd_data, fits_section=5)
+    # Do we raise an error if the input is a plain array?
+    with pytest.raises(TypeError):
+        subtract_overscan(np.zeros((10, 10)), fits_section="[1:10]")
 
 
 def test_trim_image_fits_section_requires_string():
@@ -319,13 +320,13 @@ def test_trim_image_fits_section(mask_data, uncertainty):
     if mask_data:
         ccd_data.mask = np.zeros_like(ccd_data)
     if uncertainty:
-        err = np.random.normal(size=ccd_data.shape)
+        err = np.random.default_rng().normal(size=ccd_data.shape)
         ccd_data.uncertainty = StdDevUncertainty(err)
 
     trimmed = trim_image(ccd_data, fits_section="[20:40,:]")
     # FITS reverse order, bounds are inclusive and starting index is 1-based
     assert trimmed.shape == (50, 21)
-    np.testing.assert_array_equal(trimmed.data, ccd_data[:, 19:40])
+    np.testing.assert_allclose(trimmed.data, ccd_data[:, 19:40])
     if mask_data:
         assert trimmed.shape == trimmed.mask.shape
     if uncertainty:
@@ -336,7 +337,7 @@ def test_trim_image_no_section():
     ccd_data = ccd_data_func(data_size=50)
     trimmed = trim_image(ccd_data[:, 19:40])
     assert trimmed.shape == (50, 21)
-    np.testing.assert_array_equal(trimmed.data, ccd_data[:, 19:40])
+    np.testing.assert_allclose(trimmed.data, ccd_data[:, 19:40])
 
 
 def test_trim_with_wcs_alters_wcs():
@@ -433,9 +434,7 @@ def test_subtract_dark(explicit_times, scale, exposure_keyword):
             (exptime / dark_exptime) * (exposure_unit / dark_exposure_unit)
         )
 
-    np.testing.assert_array_equal(
-        ccd_data.data - dark_scale * dark_level, dark_sub.data
-    )
+    np.testing.assert_allclose(ccd_data.data - dark_scale * dark_level, dark_sub.data)
     # Headers should have the same content...do they?
     assert dark_sub.header == ccd_data.header
     # But the headers should not be the same object -- a copy was made
@@ -529,7 +528,7 @@ def test_flat_correct():
     ccd_data.header["my_key"] = 42
     size = ccd_data.shape[0]
     # create the flat, with some scatter
-    data = 2 * np.random.normal(loc=1.0, scale=0.05, size=(size, size))
+    data = 2 * np.random.default_rng().normal(loc=1.0, scale=0.05, size=(size, size))
     flat = CCDData(data, meta=fits.header.Header(), unit=ccd_data.unit)
     flat_data = flat_correct(ccd_data, flat, add_keyword=None)
 
@@ -553,7 +552,7 @@ def test_flat_correct_min_value():
     size = ccd_data.shape[0]
 
     # Create the flat
-    data = 2 * np.random.normal(loc=1.0, scale=0.05, size=(size, size))
+    data = 2 * np.random.default_rng().normal(loc=1.0, scale=0.05, size=(size, size))
     flat = CCDData(data, meta=fits.header.Header(), unit=ccd_data.unit)
     flat_orig_data = flat.data.copy()
     min_value = 2.1  # Should replace some, but not all, values
@@ -587,7 +586,7 @@ def test_flat_correct_norm_value():
     # Note that mean value of flat is set below and is different than
     # the mean of the flat data.
     flat_mean = 5.0
-    data = np.random.normal(loc=1.0, scale=0.05, size=ccd_data.shape)
+    data = np.random.default_rng().normal(loc=1.0, scale=0.05, size=ccd_data.shape)
     flat = CCDData(data, meta=fits.Header(), unit=ccd_data.unit)
     flat_data = flat_correct(ccd_data, flat, add_keyword=None, norm_value=flat_mean)
 
@@ -606,7 +605,7 @@ def test_flat_correct_norm_value_bad_value():
     # it is given a bad norm_value. Bad means <=0.
 
     # Create the flat, with some scatter
-    data = np.random.normal(loc=1.0, scale=0.05, size=ccd_data.shape)
+    data = np.random.default_rng().normal(loc=1.0, scale=0.05, size=ccd_data.shape)
     flat = CCDData(data, meta=fits.Header(), unit=ccd_data.unit)
     with pytest.raises(ValueError) as e:
         flat_correct(ccd_data, flat, add_keyword=None, norm_value=-7)
@@ -642,7 +641,7 @@ def test_gain_correct():
     ccd_data = ccd_data_func()
     init_data = ccd_data.data
     gain_data = gain_correct(ccd_data, gain=3, add_keyword=None)
-    assert_array_equal(gain_data.data, 3 * init_data)
+    np.testing.assert_allclose(gain_data.data, 3 * init_data)
     assert ccd_data.meta == gain_data.meta
 
 
@@ -652,7 +651,7 @@ def test_gain_correct_quantity():
     g = Quantity(3, u.electron / u.adu)
     ccd_data = gain_correct(ccd_data, gain=g)
 
-    assert_array_equal(ccd_data.data, 3 * init_data)
+    np.testing.assert_allclose(ccd_data.data, 3 * init_data)
     assert ccd_data.unit == u.electron
 
 
@@ -692,7 +691,7 @@ def test_transform_image(mask_data, uncertainty):
         ccd_data.mask = np.zeros_like(ccd_data)
         ccd_data.mask[10, 10] = 1
     if uncertainty:
-        err = np.random.normal(size=ccd_data.shape)
+        err = np.random.default_rng().normal(size=ccd_data.shape)
         ccd_data.uncertainty = StdDevUncertainty(err)
 
     def tran(arr):
@@ -700,13 +699,15 @@ def test_transform_image(mask_data, uncertainty):
 
     tran = transform_image(ccd_data, tran)
 
-    assert_array_equal(10 * ccd_data.data, tran.data)
+    np.testing.assert_allclose(10 * ccd_data.data, tran.data)
     if mask_data:
         assert tran.shape == tran.mask.shape
-        assert_array_equal(ccd_data.mask, tran.mask)
+        np.testing.assert_array_equal(ccd_data.mask, tran.mask)
     if uncertainty:
         assert tran.shape == tran.uncertainty.array.shape
-        assert_array_equal(10 * ccd_data.uncertainty.array, tran.uncertainty.array)
+        np.testing.assert_allclose(
+            10 * ccd_data.uncertainty.array, tran.uncertainty.array
+        )
 
 
 # Test block_reduce and block_replicate wrapper
@@ -807,36 +808,13 @@ def test_block_replicate():
     assert "testkw2" not in ccd.meta
 
 
-# Test blockaveraging ndarray
-def test__blkavg_ndarray():
-    with pytest.raises(TypeError):
-        _blkavg(1, (5, 5))
-
-
-# Test rebinning dimensions
-def test__blkavg_dimensions():
-    ccd_data = ccd_data_func(data_size=10)
-    with pytest.raises(ValueError):
-        _blkavg(ccd_data.data, (5,))
-
-
-# Test blkavg works
-def test__blkavg_larger():
-    ccd_data = ccd_data_func(data_size=20)
-    a = ccd_data.data
-    b = _blkavg(a, (10, 10))
-
-    assert b.shape == (10, 10)
-    np.testing.assert_almost_equal(b.sum(), 0.25 * a.sum())
-
-
 # Test overscan changes
 def test__overscan_schange():
     ccd_data = ccd_data_func()
     old_data = ccd_data.copy()
     new_data = subtract_overscan(ccd_data, overscan=ccd_data[:, 1], overscan_axis=0)
     assert not np.allclose(old_data.data, new_data.data)
-    np.testing.assert_array_equal(old_data.data, ccd_data.data)
+    np.testing.assert_allclose(old_data.data, ccd_data.data)
 
 
 def test_create_deviation_does_not_change_input():
@@ -845,7 +823,7 @@ def test_create_deviation_does_not_change_input():
     _ = create_deviation(
         ccd_data, gain=5 * u.electron / u.adu, readnoise=10 * u.electron
     )
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -857,7 +835,7 @@ def test_cosmicray_median_does_not_change_input():
         _ = cosmicray_median(
             ccd_data, error_image=error, thresh=5, mbox=11, gbox=0, rbox=0
         )
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -865,7 +843,7 @@ def test_cosmicray_lacosmic_does_not_change_input():
     ccd_data = ccd_data_func()
     original = ccd_data.copy()
     _ = cosmicray_lacosmic(ccd_data)
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -875,7 +853,7 @@ def test_flat_correct_does_not_change_input():
     flat = CCDData(np.zeros_like(ccd_data), unit=ccd_data.unit)
     with np.errstate(invalid="ignore"):
         _ = flat_correct(ccd_data, flat=flat)
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -883,7 +861,7 @@ def test_gain_correct_does_not_change_input():
     ccd_data = ccd_data_func()
     original = ccd_data.copy()
     _ = gain_correct(ccd_data, gain=1, gain_unit=ccd_data.unit)
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -892,7 +870,7 @@ def test_subtract_bias_does_not_change_input():
     original = ccd_data.copy()
     master_frame = CCDData(np.zeros_like(ccd_data), unit=ccd_data.unit)
     _ = subtract_bias(ccd_data, master=master_frame)
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -900,7 +878,7 @@ def test_trim_image_does_not_change_input():
     ccd_data = ccd_data_func()
     original = ccd_data.copy()
     _ = trim_image(ccd_data, fits_section=None)
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -909,7 +887,7 @@ def test_transform_image_does_not_change_input():
     original = ccd_data.copy()
     with np.errstate(invalid="ignore"):
         _ = transform_image(ccd_data, np.sqrt)
-    np.testing.assert_array_equal(original.data, ccd_data)
+    np.testing.assert_allclose(original.data, ccd_data)
     assert original.unit == ccd_data.unit
 
 
@@ -969,7 +947,7 @@ def test_wcs_project_onto_shifted_wcs():
     target_wcs = wcs_for_testing(ccd_data.shape)
     target_wcs.wcs.crpix += [1, 1]
 
-    ccd_data.mask = np.random.choice([0, 1], size=ccd_data.shape)
+    ccd_data.mask = np.random.default_rng().choice([0, 1], size=ccd_data.shape)
 
     new_ccd = wcs_project(ccd_data, target_wcs)
 
@@ -1060,7 +1038,7 @@ def test_ccd_process_does_not_change_input():
     ccd_data = ccd_data_func()
     original = ccd_data.copy()
     _ = ccd_process(ccd_data, gain=5 * u.electron / u.adu, readnoise=10 * u.electron)
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
 
 
@@ -1133,7 +1111,7 @@ def test_ccd_process():
     # Final results should be (10 - 2) / 2.0 - 2 = 2
     # Error should be (4 + 5)**0.5 / 0.5  = 3.0
 
-    np.testing.assert_array_equal(2.0 * np.ones((100, 90)), occd.data)
+    np.testing.assert_allclose(2.0 * np.ones((100, 90)), occd.data)
     np.testing.assert_almost_equal(3.0 * np.ones((100, 90)), occd.uncertainty.array)
     np.testing.assert_array_equal(mask, occd.mask)
     assert occd.unit == u.electron
@@ -1179,7 +1157,7 @@ def test_ccd_process_gain_corrected():
     # Final results should be (10 - 2) / 2.0 - 2 = 2
     # Error should be (4 + 5)**0.5 / 0.5  = 3.0
 
-    np.testing.assert_array_equal(2.0 * np.ones((100, 90)), occd.data)
+    np.testing.assert_allclose(2.0 * np.ones((100, 90)), occd.data)
     np.testing.assert_almost_equal(3.0 * np.ones((100, 90)), occd.uncertainty.array)
     np.testing.assert_array_equal(mask, occd.mask)
     assert occd.unit == u.electron
