@@ -1,7 +1,7 @@
-from pathlib import Path
+import os
 import subprocess
 import sys
-import os
+from pathlib import Path
 
 import pytest
 
@@ -11,15 +11,23 @@ run_dir = Path(__file__).parent
 # subprocess we can add that direction to sys.path.
 subprocess_dir = run_dir.parent.parent
 
-OVERHEAD = '4'
-NUM_FILE_LIMIT = '20'
-common_args = [sys.executable, str(run_dir / 'run_with_file_number_limit.py'),
-               '--kind', 'fits', '--overhead', OVERHEAD]
+OVERHEAD = "4"
+NUM_FILE_LIMIT = "20"
+common_args = [
+    sys.executable,
+    str(run_dir / "run_with_file_number_limit.py"),
+    "--kind",
+    "fits",
+    "--overhead",
+    OVERHEAD,
+]
 
 
 # Regression test for #629
-@pytest.mark.skipif(os.environ.get('APPVEYOR') or os.sys.platform == 'win32',
-                    reason='Test relies on linux/osx features of psutil')
+@pytest.mark.skipif(
+    os.environ.get("APPVEYOR") or os.sys.platform == "win32",
+    reason="Test relies on linux/osx features of psutil",
+)
 def test_open_files_combine_no_chunks():
     """
     Test that we are not opening (much) more than the number of files
@@ -27,7 +35,7 @@ def test_open_files_combine_no_chunks():
     """
     # Make a copy
     args = list(common_args)
-    args.extend(['--open-by', 'combine-nochunk', NUM_FILE_LIMIT])
+    args.extend(["--open-by", "combine-nochunk", NUM_FILE_LIMIT])
     p = subprocess.run(args=args, cwd=str(subprocess_dir))
     # If we have succeeded the test passes. We are only checking that
     # we don't have too many files open.
@@ -35,8 +43,10 @@ def test_open_files_combine_no_chunks():
 
 
 # Regression test for #629
-@pytest.mark.skipif(os.environ.get('APPVEYOR') or os.sys.platform == 'win32',
-                    reason='Test relies on linux/osx features of psutil')
+@pytest.mark.skipif(
+    os.environ.get("APPVEYOR") or os.sys.platform == "win32",
+    reason="Test relies on linux/osx features of psutil",
+)
 def test_open_files_combine_chunks():
     """
     Test that we are not opening (much) more than the number of files
@@ -44,7 +54,7 @@ def test_open_files_combine_chunks():
     """
     # Make a copy
     args = list(common_args)
-    args.extend(['--open-by', 'combine-chunk', NUM_FILE_LIMIT])
+    args.extend(["--open-by", "combine-chunk", NUM_FILE_LIMIT])
     p = subprocess.run(args=args, cwd=str(subprocess_dir))
     # If we have succeeded the test passes. We are only checking that
     # we don't have too many files open.
