@@ -8,16 +8,16 @@ from ccdproc.core import Keyword
 
 
 def test_keyword_init():
-    key_name = 'some_key'
+    key_name = "some_key"
     key = Keyword(key_name, unit=u.second)
     assert key.name == key_name
     assert key.unit == u.second
 
 
 def test_keyword_properties_read_only():
-    key = Keyword('observer')
+    key = Keyword("observer")
     with pytest.raises(AttributeError):
-        key.name = 'error'
+        key.name = "error"
     with pytest.raises(AttributeError):
         key.unit = u.hour
 
@@ -30,17 +30,20 @@ numerical_value = 30
 #     True if the expected result is key.value == numerical_value * key.unit
 #     Name of an error if an error is expected
 #     A string if the expected value is a string
-@pytest.mark.parametrize('value,unit,expected', [
-                         (numerical_value, unit, True),
-                         (numerical_value, None, ValueError),
-                         (numerical_value * unit, None, True),
-                         (numerical_value * unit, unit, True),
-                         (numerical_value * unit, u.km, True),
-                         ('some string', None, 'some string'),
-                         ('no strings with unit', unit, ValueError)
-                         ])
+@pytest.mark.parametrize(
+    "value,unit,expected",
+    [
+        (numerical_value, unit, True),
+        (numerical_value, None, ValueError),
+        (numerical_value * unit, None, True),
+        (numerical_value * unit, unit, True),
+        (numerical_value * unit, u.km, True),
+        ("some string", None, "some string"),
+        ("no strings with unit", unit, ValueError),
+    ],
+)
 def test_value_setting(value, unit, expected):
-    name = 'exposure'
+    name = "exposure"
     # Setting at initialization time with
     try:
         expected_is_error = issubclass(expected, Exception)
@@ -58,7 +61,7 @@ def test_value_setting(value, unit, expected):
 
 
 def test_keyword_value_from_header():
-    name = 'exposure'
+    name = "exposure"
     numerical_value = 30
     unit = u.second
     h = fits.Header()
