@@ -59,7 +59,7 @@ def test_rebin_ccddata(mask_data, uncertainty):
     if mask_data:
         ccd_data.mask = np.zeros_like(ccd_data)
     if uncertainty:
-        err = np.random.normal(size=ccd_data.shape)
+        err = np.random.default_rng().normal(size=ccd_data.shape)
         ccd_data.uncertainty = StdDevUncertainty(err)
 
     with pytest.warns(AstropyDeprecationWarning):
@@ -77,5 +77,5 @@ def test_rebin_does_not_change_input():
     original = ccd_data.copy()
     with pytest.warns(AstropyDeprecationWarning):
         _ = rebin(ccd_data, (20, 20))
-    np.testing.assert_array_equal(original.data, ccd_data.data)
+    np.testing.assert_allclose(original.data, ccd_data.data)
     assert original.unit == ccd_data.unit
